<?php

/**
 * Widget de Sobre o Autor
 * 
 * @author Thiago Belem <contato@thiagobelem.net>
 * @link http://blog.thiagobelem.net/criando-seu-primeiro-widget-no-wordpress/
 */
class SobreAutorWidget extends WP_Widget {
    
    /**
     * Construtor
     */
    public function SobreAutorWidget() {
        parent::WP_Widget(false, $name = 'Sobre o autor');
    }
    
    /**
     * Exibio final do Widget (j no sidebar)
     *
     * @param array $argumentos Argumentos passados para o widget
     * @param array $instancia Instncia do widget
     */
    public function widget($argumentos, $instancia) {
        if (!is_single()) return;
        
        $autor = array(
            'nome' => get_the_author_meta('display_name'),
            'email' => get_the_author_meta('user_email'),
            'descricao' => get_the_author_meta('description'),
            'link' => get_the_author_meta('user_url')
        );
        
        // Exibe o HTML do Widget
        echo $argumentos['before_widget'];
        echo $argumentos['before_title'] . $argumentos['widget_name'] . $argumentos['after_title'];
        echo get_avatar($autor['email'], $size = '59');
        echo "<h4>{$autor['nome']}</h4>";
        echo "<p>{$autor['descricao']}</p>";
        if (isset($instancia['link_autor']) && $instancia['link_autor']) {
            echo '<p>Visite o <a href="'. $autor['link'] .'" title="'. $autor['nome'] .'" rel="nofollow" target="_blank">site do autor</a></p>';
        }
        echo $argumentos['after_widget'];
    }
    
    /**
     * Salva os dados do widget no banco de dados
     *
     * @param array $nova_instancia Os novos dados do widget (a serem salvos)
     * @param array $instancia_antiga Os dados antigos do widget
     * 
     * @return array $instancia Dados atualizados a serem salvos no banco de dados
     */
    public function update($nova_instancia, $instancia_antiga) {
        $instancia = array_merge($instancia_antiga, $nova_instancia);
        
        return $instancia;
    }
    
    /**
     * Formulrio para os dados do widget (exibido no painel de controle)
     *
     * @param array $instancia Instncia do widget
     */
    public function form($instancia) {
        $widget['link_autor'] = (boolean)$instancia['link_autor'];
        ?>
        <p><label for="<?php echo $this->get_field_id('link_autor'); ?>"><input id="<?php echo $this->get_field_id('link_autor'); ?>" name="<?php echo $this->get_field_name('link_autor'); ?>" type="checkbox" value="1" <?php if ($widget['link_autor']) echo 'checked="checked"'; ?> /> <?php _e('Exibe o link do autor'); ?></label></p>
        <?php    
    }
    
}

?>